pub struct DataBuilder { /* private fields */ }Expand description
A flexible data builder for create/update operations.
This builder allows setting fields dynamically and supports nested creates, connects, and all update operations.
Implementations
Sourceimpl DataBuilder
impl DataBuilder
Sourcepub fn set(self, field: impl Into<String>, value: impl Into<FieldValue>) -> Self
pub fn set(self, field: impl Into<String>, value: impl Into<FieldValue>) -> Self
Set a field value.
Sourcepub fn set_default(self, field: impl Into<String>) -> Self
pub fn set_default(self, field: impl Into<String>) -> Self
Set a field to its default value.
Sourcepub fn push(
self,
field: impl Into<String>,
value: impl Into<FieldValue>,
) -> Self
pub fn push( self, field: impl Into<String>, value: impl Into<FieldValue>, ) -> Self
Push a value to an array field.
Sourcepub fn connect(
self,
relation: impl Into<String>,
id: impl Into<FieldValue>,
) -> Self
pub fn connect( self, relation: impl Into<String>, id: impl Into<FieldValue>, ) -> Self
Connect to an existing related record by ID.
Sourcepub fn connect_by(
self,
relation: impl Into<String>,
field: impl Into<String>,
value: impl Into<FieldValue>,
) -> Self
pub fn connect_by( self, relation: impl Into<String>, field: impl Into<String>, value: impl Into<FieldValue>, ) -> Self
Connect to an existing related record by a specific field.
Sourcepub fn disconnect(self, relation: impl Into<String>) -> Self
pub fn disconnect(self, relation: impl Into<String>) -> Self
Disconnect from a related record.
Sourcepub fn create_nested(
self,
relation: impl Into<String>,
data: DataBuilder,
) -> Self
pub fn create_nested( self, relation: impl Into<String>, data: DataBuilder, ) -> Self
Create a nested record.
Sourcepub fn into_fields(self) -> HashMap<String, FieldValue>
pub fn into_fields(self) -> HashMap<String, FieldValue>
Get the fields map.
Sourcepub fn get(&self, field: &str) -> Option<&FieldValue>
pub fn get(&self, field: &str) -> Option<&FieldValue>
Get a field value.