AggregateInput

Trait AggregateInput 

pub trait AggregateInput {
    type Model: Model;
}
A typed shape that lowers to an aggregate spec (_count / _avg / _sum / _min / _max).

The IR target for this trait is finalized in phase 6 when aggregate macros are wired up. For phase 1 the trait only carries the Model associated type.

Required Associated Types

type Model: Model

The model this aggregate spec applies to.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors